autowisp.database.data_model.light_curve_processing_progress module — AutoWISP documentation

# autowisp.database.data_model.light_curve_processing_progress module

## Class Inheritance Diagram

Define table tracknig what processing has been applied to which LCs.

class autowisp.database.data_model.light_curve_processing_progress.LightCurveProcessingProgress(**kwargs)

  Bases: `DataModelBase`

  The table describing the light curve processing progress

  configuration_version

    config version of image

  final

    Is this the final processing status? The only case where `status=1` is not final is for magnitude fitting, where there may be additional iterations needed.

  finished

    The time processing is known to have ended (NULL if possibly still on-going)

  host

    Hostname or other identifier of the computer where processing is/was done

  id

    A unique identifier for each row.

  notes

    Any user supplied notes about the processing.

  process_id

    Identifier of the process performing this calibration step

  single_photref_id

    The ID of the single photometric reference for which LC points were processed.

  sphotref
  started

    The time processing started

  step
  step_id

    Id of the step that was applied

  timestamp

    When record was last changed